@@ -53,12 +53,9 @@ ContactWidget::ContactWidget(QWidget *parent, Contact* contact, QPixmap* default
     }
     m_Layout->addWidget(lbl, 0, 0, 2, 1);
 
-    lbl = new QLabel(this);
-    lbl->setText(m_Contact->Name);
-    QFont f = lbl->font();
-    f.setBold(true);
-    lbl->setFont(f);
-    m_Layout->addWidget(lbl, 0, 1, 1, 1);
+    m_NameLabel = new QLabel(this);
+    m_NameLabel->setText(QString("<b>%1</b>").arg(m_Contact->Name));
+    m_Layout->addWidget(m_NameLabel, 0, 1, 1, 1);
 
     lbl = new QLabel(this);
     lbl->setText(m_Contact->MobileNumber);
@@ -105,3 +102,11 @@ void ContactWidget::enterEvent(QEvent*)
 bool ContactWidget::IsPressed(){
     return m_Sunken;
 }
+
+void ContactWidget::SelectText(QString select)
+{
+    QString text = m_Contact->Name;
+    text.replace(select, QString("<b>%1</b>").arg(select), Qt::CaseInsensitive);
+    m_NameLabel->setText(text);
+    m_NameLabel->update();
+}
